==> types_boto3_license_manager-1.35.71-py3-none-any.whl: types_boto3_license_manager/paginator.py <==
"""
Type annotations for license-manager service client paginators.

[Open documentation](https://youtype.github.io/types_boto3_docs/types_boto3_license_manager/paginators/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_license_manager.client import LicenseManagerClient
    from types_boto3_license_manager.paginator import (
        ListAssociationsForLicenseConfigurationPaginator,
        ListLicenseConfigurationsPaginator,
        ListLicenseSpecificationsForResourcePaginator,
        ListResourceInventoryPaginator,
        ListUsageForLicenseConfigurationPaginator,
    )

    session = Session()
    client: LicenseManagerClient = session.client("license-manager")

    list_associations_for_license_configuration_paginator: ListAssociationsForLicenseConfigurationPaginator = client.get_paginator("list_associations_for_license_configuration")
    list_license_configurations_paginator: ListLicenseConfigurationsPaginator = client.get_paginator("list_license_configurations")
    list_license_specifications_for_resource_paginator: ListLicenseSpecificationsForResourcePaginator = client.get_paginator("list_license_specifications_for_resource")
    list_resource_inventory_paginator: ListResourceInventoryPaginator = client.get_paginator("list_resource_inventory")
    list_usage_for_license_configuration_paginator: ListUsageForLicenseConfigurationPaginator = client.get_paginator("list_usage_for_license_configuration")
    ```

Copyright 2024 Vlad Emelianov
"""

import sys
from typing import Generic, Iterator, TypeVar

from botocore.paginate import PageIterator, Paginator

from .type_defs import (
    ListAssociationsForLicenseConfigurationRequestListAssociationsForLicenseConfigurationPaginateTypeDef,
    ListAssociationsForLicenseConfigurationResponseTypeDef,
    ListLicenseConfigurationsRequestListLicenseConfigurationsPaginateTypeDef,
    ListLicenseConfigurationsResponseTypeDef,
    ListLicenseSpecificationsForResourceRequestListLicenseSpecificationsForResourcePaginateTypeDef,
    ListLicenseSpecificationsForResourceResponseTypeDef,
    ListResourceInventoryRequestListResourceInventoryPaginateTypeDef,
    ListResourceInventoryResponseTypeDef,
    ListUsageForLicenseConfigurationRequestListUsageForLicenseConfigurationPaginateTypeDef,
    ListUsageForLicenseConfigurationResponseTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = (
    "ListAssociationsForLicenseConfigurationPaginator",
    "ListLicenseConfigurationsPaginator",
    "ListLicenseSpecificationsForResourcePaginator",
    "ListResourceInventoryPaginator",
    "ListUsageForLicenseConfigurationPaginator",
)


_ItemTypeDef = TypeVar("_ItemTypeDef")


class _PageIterator(PageIterator, Generic[_ItemTypeDef]):
    def __iter__(self) -> Iterator[_ItemTypeDef]:
        """
        Proxy method to specify iterator item type.
        """


class ListAssociationsForLicenseConfigurationPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/license-manager/paginator/ListAssociationsForLicenseConfiguration.html#LicenseManager.Paginator.ListAssociationsForLicenseConfiguration)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_license_manager/paginators/#listassociationsforlicenseconfigurationpaginator)
    """

    def paginate(
        self,
        **kwargs: Unpack[
            ListAssociationsForLicenseConfigurationRequestListAssociationsForLicenseConfigurationPaginateTypeDef
        ],
    ) -> _PageIterator[ListAssociationsForLicenseConfigurationResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/license-manager/paginator/ListAssociationsForLicenseConfiguration.html#LicenseManager.Paginator.ListAssociationsForLicenseConfiguration.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_license_manager/paginators/#listassociationsforlicenseconfigurationpaginator)
        """


class ListLicenseConfigurationsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/license-manager/paginator/ListLicenseConfigurations.html#LicenseManager.Paginator.ListLicenseConfigurations)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_license_manager/paginators/#listlicenseconfigurationspaginator)
    """

    def paginate(
        self,
        **kwargs: Unpack[ListLicenseConfigurationsRequestListLicenseConfigurationsPaginateTypeDef],
    ) -> _PageIterator[ListLicenseConfigurationsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/license-manager/paginator/ListLicenseConfigurations.html#LicenseManager.Paginator.ListLicenseConfigurations.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_license_manager/paginators/#listlicenseconfigurationspaginator)
        """


class ListLicenseSpecificationsForResourcePaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/license-manager/paginator/ListLicenseSpecificationsForResource.html#LicenseManager.Paginator.ListLicenseSpecificationsForResource)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_license_manager/paginators/#listlicensespecificationsforresourcepaginator)
    """

    def paginate(
        self,
        **kwargs: Unpack[
            ListLicenseSpecificationsForResourceRequestListLicenseSpecificationsForResourcePaginateTypeDef
        ],
    ) -> _PageIterator[ListLicenseSpecificationsForResourceResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/license-manager/paginator/ListLicenseSpecificationsForResource.html#LicenseManager.Paginator.ListLicenseSpecificationsForResource.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_license_manager/paginators/#listlicensespecificationsforresourcepaginator)
        """


class ListResourceInventoryPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/license-manager/paginator/ListResourceInventory.html#LicenseManager.Paginator.ListResourceInventory)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_license_manager/paginators/#listresourceinventorypaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListResourceInventoryRequestListResourceInventoryPaginateTypeDef]
    ) -> _PageIterator[ListResourceInventoryResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/license-manager/paginator/ListResourceInventory.html#LicenseManager.Paginator.ListResourceInventory.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_license_manager/paginators/#listresourceinventorypaginator)
        """


class ListUsageForLicenseConfigurationPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/license-manager/paginator/ListUsageForLicenseConfiguration.html#LicenseManager.Paginator.ListUsageForLicenseConfiguration)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_license_manager/paginators/#listusageforlicenseconfigurationpaginator)
    """

    def paginate(
        self,
        **kwargs: Unpack[
            ListUsageForLicenseConfigurationRequestListUsageForLicenseConfigurationPaginateTypeDef
        ],
    ) -> _PageIterator[ListUsageForLicenseConfigurationResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/license-manager/paginator/ListUsageForLicenseConfiguration.html#LicenseManager.Paginator.ListUsageForLicenseConfiguration.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_license_manager/paginators/#listusageforlicenseconfigurationpaginator)
        """

==> types_boto3_license_manager-1.36.0-py3-none-any.whl: types_boto3_license_manager/paginator.py <==
"""
Type annotations for license-manager service client paginators.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_license_manager/paginators/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_license_manager.client import LicenseManagerClient
    from types_boto3_license_manager.paginator import (
        ListAssociationsForLicenseConfigurationPaginator,
        ListLicenseConfigurationsPaginator,
        ListLicenseSpecificationsForResourcePaginator,
        ListResourceInventoryPaginator,
        ListUsageForLicenseConfigurationPaginator,
    )

    session = Session()
    client: LicenseManagerClient = session.client("license-manager")

    list_associations_for_license_configuration_paginator: ListAssociationsForLicenseConfigurationPaginator = client.get_paginator("list_associations_for_license_configuration")
    list_license_configurations_paginator: ListLicenseConfigurationsPaginator = client.get_paginator("list_license_configurations")
    list_license_specifications_for_resource_paginator: ListLicenseSpecificationsForResourcePaginator = client.get_paginator("list_license_specifications_for_resource")
    list_resource_inventory_paginator: ListResourceInventoryPaginator = client.get_paginator("list_resource_inventory")
    list_usage_for_license_configuration_paginator: ListUsageForLicenseConfigurationPaginator = client.get_paginator("list_usage_for_license_configuration")
    ```

Copyright 2025 Vlad Emelianov
"""

from __future__ import annotations

import sys
from typing import TYPE_CHECKING

from botocore.paginate import PageIterator, Paginator

from .type_defs import (
    ListAssociationsForLicenseConfigurationRequestPaginateTypeDef,
    ListAssociationsForLicenseConfigurationResponseTypeDef,
    ListLicenseConfigurationsRequestPaginateTypeDef,
    ListLicenseConfigurationsResponseTypeDef,
    ListLicenseSpecificationsForResourceRequestPaginateTypeDef,
    ListLicenseSpecificationsForResourceResponseTypeDef,
    ListResourceInventoryRequestPaginateTypeDef,
    ListResourceInventoryResponseTypeDef,
    ListUsageForLicenseConfigurationRequestPaginateTypeDef,
    ListUsageForLicenseConfigurationResponseTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = (
    "ListAssociationsForLicenseConfigurationPaginator",
    "ListLicenseConfigurationsPaginator",
    "ListLicenseSpecificationsForResourcePaginator",
    "ListResourceInventoryPaginator",
    "ListUsageForLicenseConfigurationPaginator",
)


if TYPE_CHECKING:
    _ListAssociationsForLicenseConfigurationPaginatorBase = Paginator[
        ListAssociationsForLicenseConfigurationResponseTypeDef
    ]
else:
    _ListAssociationsForLicenseConfigurationPaginatorBase = Paginator  # type: ignore[assignment]


class ListAssociationsForLicenseConfigurationPaginator(
    _ListAssociationsForLicenseConfigurationPaginatorBase
):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/license-manager/paginator/ListAssociationsForLicenseConfiguration.html#LicenseManager.Paginator.ListAssociationsForLicenseConfiguration)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_license_manager/paginators/#listassociationsforlicenseconfigurationpaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListAssociationsForLicenseConfigurationRequestPaginateTypeDef]
    ) -> PageIterator[ListAssociationsForLicenseConfigurationResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/license-manager/paginator/ListAssociationsForLicenseConfiguration.html#LicenseManager.Paginator.ListAssociationsForLicenseConfiguration.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_license_manager/paginators/#listassociationsforlicenseconfigurationpaginator)
        """


if TYPE_CHECKING:
    _ListLicenseConfigurationsPaginatorBase = Paginator[ListLicenseConfigurationsResponseTypeDef]
else:
    _ListLicenseConfigurationsPaginatorBase = Paginator  # type: ignore[assignment]


class ListLicenseConfigurationsPaginator(_ListLicenseConfigurationsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/license-manager/paginator/ListLicenseConfigurations.html#LicenseManager.Paginator.ListLicenseConfigurations)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_license_manager/paginators/#listlicenseconfigurationspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListLicenseConfigurationsRequestPaginateTypeDef]
    ) -> PageIterator[ListLicenseConfigurationsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/license-manager/paginator/ListLicenseConfigurations.html#LicenseManager.Paginator.ListLicenseConfigurations.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_license_manager/paginators/#listlicenseconfigurationspaginator)
        """


if TYPE_CHECKING:
    _ListLicenseSpecificationsForResourcePaginatorBase = Paginator[
        ListLicenseSpecificationsForResourceResponseTypeDef
    ]
else:
    _ListLicenseSpecificationsForResourcePaginatorBase = Paginator  # type: ignore[assignment]


class ListLicenseSpecificationsForResourcePaginator(
    _ListLicenseSpecificationsForResourcePaginatorBase
):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/license-manager/paginator/ListLicenseSpecificationsForResource.html#LicenseManager.Paginator.ListLicenseSpecificationsForResource)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_license_manager/paginators/#listlicensespecificationsforresourcepaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListLicenseSpecificationsForResourceRequestPaginateTypeDef]
    ) -> PageIterator[ListLicenseSpecificationsForResourceResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/license-manager/paginator/ListLicenseSpecificationsForResource.html#LicenseManager.Paginator.ListLicenseSpecificationsForResource.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_license_manager/paginators/#listlicensespecificationsforresourcepaginator)
        """


if TYPE_CHECKING:
    _ListResourceInventoryPaginatorBase = Paginator[ListResourceInventoryResponseTypeDef]
else:
    _ListResourceInventoryPaginatorBase = Paginator  # type: ignore[assignment]


class ListResourceInventoryPaginator(_ListResourceInventoryPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/license-manager/paginator/ListResourceInventory.html#LicenseManager.Paginator.ListResourceInventory)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_license_manager/paginators/#listresourceinventorypaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListResourceInventoryRequestPaginateTypeDef]
    ) -> PageIterator[ListResourceInventoryResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/license-manager/paginator/ListResourceInventory.html#LicenseManager.Paginator.ListResourceInventory.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_license_manager/paginators/#listresourceinventorypaginator)
        """


if TYPE_CHECKING:
    _ListUsageForLicenseConfigurationPaginatorBase = Paginator[
        ListUsageForLicenseConfigurationResponseTypeDef
    ]
else:
    _ListUsageForLicenseConfigurationPaginatorBase = Paginator  # type: ignore[assignment]


class ListUsageForLicenseConfigurationPaginator(_ListUsageForLicenseConfigurationPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/license-manager/paginator/ListUsageForLicenseConfiguration.html#LicenseManager.Paginator.ListUsageForLicenseConfiguration)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_license_manager/paginators/#listusageforlicenseconfigurationpaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListUsageForLicenseConfigurationRequestPaginateTypeDef]
    ) -> PageIterator[ListUsageForLicenseConfigurationResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/license-manager/paginator/ListUsageForLicenseConfiguration.html#LicenseManager.Paginator.ListUsageForLicenseConfiguration.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_license_manager/paginators/#listusageforlicenseconfigurationpaginator)
        """
